Nature-based solutions through collective actions for spatial justice in urban green commons - ScienceDirect
Description: Urban climate adaptation through nature-based solutions (NBS) requires collective action that incorporates spatial justice considerations. Collective …

Skip to main content Skip to article

- View PDF

Search ScienceDirect

## Environmental Science & Policy

Volume 145, July 2023, Pages 228-237

# Nature-based solutions through collective actions for spatial justice in urban green commons

Author links open overlay panel
,
https://doi.org/10.1016/j.envsci.2023.04.016
Get rights and content
Under a Creative Commons license
open access

## Highlights

- •

  Nature-based solutions (NBS) are not a phenomenon driven by policy-makers.

- •

  Collective action for spatial justice is essential to providing just NBS in cities.

- •

  New forms of relationships through collective action led to the protection of urban green commons in Istanbul.

- •

  Just NBS positions urban green infrastructures as an essential lever of climate adaptation.

## Abstract

Urban climate adaptation through nature-based solutions (NBS) requires collective action that incorporates spatial justice considerations. Collective actions reveal new ways of thinking about urban green commons and spatial justice by reframing conventional understandings of NBS, space, and climate adaptation. Three urban green commons examined in Istanbul demonstrate how the grassroots-supported NBS must navigate complex land ownership arrangements, spatial justice, and opposing urban development priorities and socio-spatial reconfigurations spurred by local and national political elites. Using qualitative data collected from fieldwork carried out in 2019, we find critical relationships between activists, academics, professional organizations, and local residents collectively acting to promote urban green commons. NBS do not rely on the dominant techno-political processes that generate primarily infrastructure-based climate adaptation solutions in Istanbul. While spatial justice and collective action scholarship often pays attention to how disadvantaged communities gain recognition and involvement in decision making - such as establishing formal channels to access environmental goods and services - climate adaptation through NBS opens spaces of opportunity for these groups to promote justice and resist the dominant economic development paradigm. Further studies must pay attention to what extent collective actions create new socio-political identities that are harnessed to resist dominant techno-political processes, and when are these emergent identities co-opted by local and national governments.

## Keywords

Climate adaptation
Spatial justice
Collective action
Urban green commons
Istanbul
Turkey

## Data availability

The data that has been used is confidential.

## Cited by (0)

© 2023 The Author(s). Published by Elsevier Ltd.
No articles found.
View article metrics